Const IniFile As String = "PowerMeter.ini"

Const MeterDev As String = "Q3"
Const TodayDev As String = "A1"
Const YesterdayDev As String = "A2"
Const ThisWeekDev As String = "A3"
Const LastWeekDev As String = "A4"

Sub UpdateValues(Optional ByVal parms As String = "")

    'Get current and last readings then calculate used value
    Dim LastRead, CurntRead, Used As Integer

    Try
        LastRead = CInt(hs.GetINISetting("PowerMeter", "LastRead", "0", IniFile))
        CurntRead = hs.DeviceValue(MeterDev)
        If CurntRead >= LastRead Then
            Used = CurntRead - LastRead
            hs.SaveINISetting("PowerMeter", "LastRead", CStr(CurntRead), IniFile)
        Else
            hs.WriteLog("PowerMeter", "Error. Current reading is less than last reading!")
        End If
    Catch ex As Exception
        hs.WriteLog("PowerMeter", "Error getting current reading " & ex.ToString)
        Exit Sub
    End Try

    'Update devices
    Dim NewValue As Integer
    Dim LastValue As Integer
    Dim NewString As String

    'For today device
    LastValue = hs.DeviceValue(TodayDev)
    NewValue = LastValue + Used
    NewString = CStr(FormatNumber(NewValue / 100, 2)) & " kWh"
    hs.SetDeviceValue(TodayDev, NewValue)
    hs.SetDeviceString(TodayDev, NewString, True)

    'For this week device
    LastValue = hs.DeviceValue(ThisWeekDev)
    NewValue = LastValue + Used
    NewString = CStr(FormatNumber(NewValue / 100, 2)) & " kWh"
    hs.SetDeviceValue(ThisWeekDev, NewValue)
    hs.SetDeviceString(ThisWeekDev, NewString, True)

End Sub

Sub ResetCounters(Optional ByVal Parms As String = "")

    Dim Hr As Single = Hour(Now())
    Dim Mi As Single = Minute(Now())
    Dim Mt As Single = Month(Now())
    Dim Dy As Single = Day(Now())
    Dim WkStDay As String = "2" 'Monday

    'A little check to make sure this function is only run between 00:00:00 and 00:01:00
    If Hr = 0 And Mi < 1 Then

        'Reset day counters
        hs.SetDeviceValue(YesterdayDev, hs.DeviceValue(TodayDev))
        hs.SetDeviceString(YesterdayDev, hs.DeviceString(TodayDev), True)
        hs.SetDeviceValue(TodayDev, 0)
        hs.SetDeviceString(TodayDev, "0 kWh", True)
        hs.WriteLog("PowerMeter", "Day counters have been reset.")

        'Reset week counters
        If CStr(Weekday(Now())) = WkStDay Then
            hs.SetDeviceValue(LastWeekDev, hs.DeviceValue(ThisWeekDev))
            hs.SetDeviceString(LastWeekDev, hs.DeviceString(ThisWeekDev), True)
            hs.SetDeviceValue(ThisWeekDev, 0)
            hs.SetDeviceString(ThisWeekDev, "0 kWh", True)
            hs.WriteLog("PowerMeter", "Week counters have been reset.")
        End If

        If Dy = 1 Then
            'Put code here for month devices reset
            hs.WriteLog("PowerMeter", "Month counters have been reset.")
        End If

        If Dy = 1 And Mt = 1 Then
            'Put code here for year devices reset
            hs.WriteLog("PowerMeter", "Month counters have been reset.")
        End If
    Else
        hs.WriteLog("PowerMeter", "Error. Counters can only be reset between 00:00:00 and 00:01:00")
    End If

End Sub
